/**
 * Tencent is pleased to support the open source community by making CloudBaseFramework - 云原生一体化部署工具 available.
 *
 * Copyright (C) 2020 THL A29 Limited, a Tencent company.  All rights reserved.
 *
 * Please refer to license text included with this package for license details.
 */
import { Plugin, PluginServiceApi } from '@cloudbase/framework-core';
/**
 * 导出接口用于生成 JSON Schema 来进行智能提示
 */
export interface IFrameworkPluginAuthInputs {
    configs: IAuthConfig[];
}
export interface IAuthConfig {
    /**
     * 登录平台
     */
    platform: 'NONLOGIN' | 'ANONYMOUS';
    /**
     * 开通状态
     */
    status: 'ENABLE' | 'DISABLE';
    /**
     * 登录平台的 AppID，选填
     */
    platformId: string;
    /**
     * 登录平台的 AppSecret，选填
     */
    platformSecret: string;
}
declare class AuthPlugin extends Plugin {
    name: string;
    api: PluginServiceApi;
    inputs: IFrameworkPluginAuthInputs;
    protected resolvedInputs: IFrameworkPluginAuthInputs;
    protected buildOutput: any;
    constructor(name: string, api: PluginServiceApi, inputs: IFrameworkPluginAuthInputs);
    /**
     * 初始化
     */
    init(): Promise<void>;
    /**
     * 执行本地命令
     */
    run(): Promise<void>;
    /**
     * 删除资源
     */
    remove(): Promise<void>;
    /**
     * 生成代码
     */
    genCode(): Promise<void>;
    /**
     * 构建
     */
    build(): Promise<void>;
    /**
     * 生成SAM文件
     */
    compile(): Promise<{
        Config: {
            Login: {
                Platform: "NONLOGIN" | "ANONYMOUS";
                PlatformId: string;
                PlatformSecret: string;
                Status: "ENABLE" | "DISABLE";
            }[];
        };
    }>;
    /**
     * 部署
     */
    deploy(): Promise<void>;
}
export declare const plugin: typeof AuthPlugin;
export {};
//# sourceMappingURL=index.d.ts.map